@@ -367,6 +367,9 @@ void CScoresheet::softkeyClicked()
 
 void CScoresheet::clear()
 {
+    if( win->rect().width() < win->rect().height() )
+        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+
 	if( dlg_confirmation->exec() )
 	{
 		if( table->item(lastcellRow,lastcellCol) ) {
@@ -377,6 +380,8 @@ void CScoresheet::clear()
 		table->clearContents();
 		resizeTable();
 	}
+
+	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 }
 
 void CScoresheet::resizeTable()
@@ -406,8 +411,13 @@ void CScoresheet::showSetup()
 	stp_list->addItems(names);
 	for(int i=0; i<sizeX; i++)
 		stp_list->item(i)->setFlags(stp_list->item(i)->flags() | Qt::ItemIsEditable);
-	
+
+    if( win->rect().width() < win->rect().height() )
+        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+
 	win_setup->show();
+
+    win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 }
 
 void CScoresheet::saveSetup()
@@ -495,9 +505,15 @@ void CScoresheet::createSetup()
 
 void CScoresheet::save()
 {
+
+	if( win->rect().width() < win->rect().height() )
+		win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+
 	QString fname = QFileDialog::getSaveFileName(win, "Save file",
 		defaultDirectory+"/"+lastFileName, "Comma Separated Values (*.csv)");
 		
+	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+
 	if( fname!=NULL && !fname.endsWith(".csv") )
 		fname.append(".csv");
 	
@@ -535,9 +551,14 @@ void CScoresheet::save()
 
 void CScoresheet::load()
 {
+    if( win->rect().width() < win->rect().height() )
+        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+
 	QString fname = QFileDialog::getOpenFileName(win, "Load file",
 		defaultDirectory, "Comma Separated Values (*.csv)");
 
+	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+
 	if( fname != NULL )
 	{
 		defaultDirectory = fname.section("/",0,-2);
@@ -602,4 +623,12 @@ void CScoresheet::load()
 	}
 }
 
+void CScoresheet::showAbout()
+{
+    if( win->rect().width() < win->rect().height() )
+        win->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
 
+	dlg_about->exec();
+
+	win->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+}
